| Title: | Shapley Value Regression for Relative Importance of Attributes |
|---|---|
| Description: | Shapley Value Regression for calculating the relative importance of independent variables in linear regression with avoiding the collinearity. |
| Authors: | Jingyi Liang |
| Maintainer: | Jingyi Liang <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.0 |
| Built: | 2026-06-03 08:17:03 UTC |
| Source: | https://github.com/cran/ShapleyValue |
Shapley Value Regression for calculating the relative importance of independent variables in linear regression with avoiding the collinearity.
y A coloumn or data set of the dependent variable
x A matrix or data set of the independent variables
The structure of the output is a datatable, with two rows:the unstandardized and standardized relative importance of each attributes using shapley value regression method.
library(MASS) library(tidyverse) data <- Boston y <- data$medv x <- as.data.frame(data[,5:8]) shapleyvalue(y,x)library(MASS) library(tidyverse) data <- Boston y <- data$medv x <- as.data.frame(data[,5:8]) shapleyvalue(y,x)