Welcome to ClientVPS Mirrors

Help for package ShapleyValue
Type: Package
Title: Shapley Value Regression for Relative Importance of Attributes
Version: 0.2.0
Author: Jingyi Liang
Maintainer: Jingyi Liang <jingyiliang19@163.com>
Description: Shapley Value Regression for calculating the relative importance of independent variables in linear regression with avoiding the collinearity.
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.1.1
Suggests: knitr, rmarkdown
Imports: tidyverse,kableExtra,MASS,utils
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-07-27 02:54:36 UTC; liji0004
Repository: CRAN
Date/Publication: 2021-07-27 04:50:01 UTC

ShapleyValueRegression – to calculate the relative importance of attributes in linear regression

Description

Shapley Value Regression for calculating the relative importance of independent variables in linear regression with avoiding the collinearity.

Arguments

y A coloumn or data set of the dependent variable

x A matrix or data set of the independent variables

Value

The structure of the output is a datatable, with two rows:the unstandardized and standardized relative importance of each attributes using shapley value regression method.

Examples

library(MASS)
library(tidyverse)
data <- Boston
y <- data$medv
x <- as.data.frame(data[,5:8])
shapleyvalue(y,x)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.